TranscribeModel class abstract

Implementers

Constructors

TranscribeModel()

Properties

hashCode → int
The hash code for this object.
no setterinherited
onMicVolumeChange → Stream<double>
no setter
onSilenceChange → Stream<bool>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transcribed → Stream<String>
no setter

Methods

dispose() → void
endTranscription() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startTranscribe() → Future<void>
toString() → String
A string representation of this object.
inherited
transcribeFromFile(File file) → Future<String>
This method should not add strings to the transcribed stream.

Operators

operator ==(Object other) → bool
The equality operator.
inherited