vit_gpt_dart_api library
Classes
- Assistant
- AssistantsModel
- AudioPlayer
- AudioRecorderModel
- Models the interface of a audio recorder.
- CompletionModel
- CompletionRepository
- Conversation
- ConversationRepository
- Handles the flow of asking and streaming the response.
- DynamicFactories
- ImageGenerationModel
- ImageGenerationRepository
- LocalStorageModel
- Message
- OpenaiRealtimeRepository
- RealtimeModel
- SimpleAudioPlayer
- SpeakerHandler
- SpeakerHandler handles the streaming and conversion of text into audio files. It is responsible for processing text chunks, generating audio for sentences, and managing the playback of these audio files using a specified audio player.
- ThreadsModel
- ThreadsRepository
- TranscribeModel
- TranscriberRepository
- TTSModel
- TTSRepository
- VitGptDartConfiguration
- VoiceRecorderHandler
Functions
-
askAssistant(
{required String assistantId, required String threadId}) → Stream< String> -
createImageGenerationRepository(
) → ImageGenerationRepository -
createRealtimeRepository(
) → RealtimeModel -
createThread(
) → Future< Conversation> -
createThreadsRepository(
) → ThreadsModel -
createTranscriberRepository(
) → TranscribeModel -
deleteSavedThread(
String id) → Future< void> -
deleteThread(
String id) → Future< void> -
downloadTTSfile(
{required String voice, required String input, Directory? folder}) → Future< File> -
findAssistants(
) → Future< List< Assistant> > -
getApiToken(
) → Future< String?> -
getMicSendMode(
) → Future< MicSendMode> -
getSavedGptModel(
) → Future< String?> -
getSavedThreadIds(
) → Future< List< String> > -
getSavedThreadsTtl(
) → Future< Duration> -
getThreadsTitle(
Iterable< String> ids) → Future<Map< String, String> > -
getThreadTitle(
String id) → Future< String?> -
getTranscriptionLanguage(
) → Future< String?> -
getTtsQuality(
) → Future< bool> - Returns true for high quality.
-
loadThread(
String id) → Future< Conversation?> -
loadThreadMessages(
String threadId) → Future< List< Message> > -
saveGptModel(
String model) → Future< void> -
saveMicSendMode(
MicSendMode mode) → Future< void> -
saveThread(
String threadId, Map< String, String> metadata) → Future<void> -
saveThreadId(
String id) → Future< void> -
saveThreadsTtl(
Duration duration) → Future< void> -
saveThreadTitle(
String id, String title) → Future< void> -
saveTranscriptionLanguage(
String lang) → Future< void> -
saveTtsQuality(
bool highQuality) → Future< void> -
transcribe(
File file) → Future< String> -
updateApiToken(
String token) → Future< void>